@@ -12,11 +12,12 @@ package org.gnu.gtk;
 import java.util.Vector;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.TextBufferEvent;
 import org.gnu.gtk.event.TextBufferListener;
-import org.gnu.gtk.event.GtkEventType;
 
 /**
  * The TextBuffer is the object used to store data to be displayed in a {@link
@@ -32,7 +33,7 @@ public class TextBuffer extends GObject {
 	/**
 	 * Create butter from native handle 
 	 * */
-	protected TextBuffer(int handle) {
+	protected TextBuffer(Handle handle) {
 		super(handle);
 	}
 	/**
@@ -60,10 +61,14 @@ public class TextBuffer extends GObject {
 	}
 
 	/**
-	 * Gets the number of characters in the buffer; note that characters and
-	 * bytes are not the same, you can't e.g. expect the contents of the buffer
-	 * in string form to be this many bytes long. The character count is cached,
-	 * so this function is very fast.
+ Gets the number of characters in the buffer. Note that
+	 * characters and
+ bytes are not the same. You can't expect
+	 * the contents of the buffer
+ in string form to be this many
+	 * bytes long. The character count is cached,
+ so this
+	 * function is very fast.
 	 * @return Number of characters in the buffer.
 	 */
 	public int getCharCount() {
@@ -75,8 +80,8 @@ public class TextBuffer extends GObject {
 	 * @return Associated TextTagTable.
 	 */
 	public TextTagTable getTextTagTable() {
-		int hndl = gtk_text_buffer_get_tag_table(getHandle());
-		GObject obj = retrieveGObject(hndl);
+	    Handle hndl = gtk_text_buffer_get_tag_table(getHandle());
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (TextTagTable)obj;
 		return new TextTagTable(hndl);
@@ -92,8 +97,6 @@ public class TextBuffer extends GObject {
 	 * @param text The text to insert
 	 */
 	public void insertText(TextIter iter, String text) {
-	    if (null == text)
-	        text = "";
 		gtk_text_buffer_insert(getHandle(), iter.getHandle(), text);
 	}
 
@@ -102,8 +105,6 @@ public class TextBuffer extends GObject {
 	 * @param text The text to insert
 	 */
 	public void insertText(String text) {
-	    if (null == text)
-	        text = "";
 		gtk_text_buffer_insert_at_cursor(getHandle(), text);
 	}
 
@@ -123,8 +124,6 @@ public class TextBuffer extends GObject {
 	 * @return Whether text was actually inserted
 	 */
 	public boolean insertTextInteractive(TextIter iter, String text, boolean defaultEditable) {
-	    if (null == text)
-	        text = "";
 		return gtk_text_buffer_insert_interactive(getHandle(), iter.getHandle(), text, defaultEditable);
 	}
 
@@ -140,8 +139,6 @@ public class TextBuffer extends GObject {
 	 * @return Whether text was actually inserted.
 	 */
 	public boolean insertTextInteractive(String text, boolean defaultEditable) {
-	    if (null == text)
-	        text = "";
 		return gtk_text_buffer_insert_interactive_at_cursor(getHandle(), text, defaultEditable);
 	}
 
@@ -170,10 +167,6 @@ public class TextBuffer extends GObject {
 	 * @param tag name of TextTag to apply to that text.
 	 */
 	public void insertText( TextIter iter, String text, String tag ){
-	    if (null == text)
-	        text = "";
-	    if (null == tag)
-	        tag = "";
 		insert_with_tag( getHandle(), iter.getHandle(), text, tag );
 	}
 
@@ -185,8 +178,6 @@ public class TextBuffer extends GObject {
 	 * @param tags Array of TextTag names to apply to that text.
 	 */
 	public void insertText( TextIter iter, String text, String[] tags ){
-	    if (null == text)
-	        text = "";
 		TextMark mark = createMark( "jginternal", getEndIter(), true);
 		insertText(iter, text );
 		TextIter start = getIter( mark );
@@ -252,8 +243,6 @@ public class TextBuffer extends GObject {
 	 * @param text The text to use as the content of the buffer.
 	 */
 	public void setText(String text) {
-	    if (null == text)
-	        text = "";
 		gtk_text_buffer_set_text(getHandle(), text);
 	}
 
@@ -368,8 +357,6 @@ public class TextBuffer extends GObject {
 	 * @param where New location for mark
 	 */
 	public void moveMark(String name, TextIter where) {
-	    if (null == name)
-	        name = "";
 		gtk_text_buffer_move_mark_by_name(getHandle(), name, where.getHandle());
 	}
 
@@ -391,8 +378,6 @@ public class TextBuffer extends GObject {
 	 * @param name The name of the mark to delete
 	 */
 	public void deleteMark(String name) {
-	    if (null == name)
-	        name = "";
 		gtk_text_buffer_delete_mark_by_name(getHandle(), name);
 	}
 
@@ -400,21 +385,17 @@ public class TextBuffer extends GObject {
 	 * Returns true if a mark exists with the given name.
 	 */
 	public boolean markExists(String name) {
-	    if (null == name)
-	        name = "";
-		return (gtk_text_buffer_get_mark(getHandle(), name) != 0);
+		return (gtk_text_buffer_get_mark(getHandle(), name) != null);
 	}
 
 	/**
 	 * Returns the mark named <code>name</code> in the buffer, or <code>null</code> if no such mark exists in the buffer
 	 */
 	public TextMark getMark(String name) {
-	    if (null == name)
-	        name = "";
-		int markHandle = gtk_text_buffer_get_mark(getHandle(), name);
-		if (0 == markHandle)
+	    Handle markHandle = gtk_text_buffer_get_mark(getHandle(), name);
+		if (null == markHandle)
 			return null;
-		GObject obj = retrieveGObject(markHandle);
+		GObject obj = getGObjectFromHandle(markHandle);
 		if (null != obj)
 			return (TextMark)obj;
 		return new TextMark(markHandle);
@@ -427,8 +408,8 @@ public class TextBuffer extends GObject {
 	 * @return Insertion point mark
 	 */
 	public TextMark getInsert() {
-		int hndl = gtk_text_buffer_get_insert(getHandle());
-		GObject obj = retrieveGObject(hndl);
+	    Handle hndl = gtk_text_buffer_get_insert(getHandle());
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (TextMark)obj;
 		return new TextMark(hndl);
@@ -445,8 +426,8 @@ public class TextBuffer extends GObject {
 	 * @return Mark for the selection
 	 */
 	public TextMark getSelectionBound() {
-		int hndl = gtk_text_buffer_get_selection_bound(getHandle());
-		GObject obj = retrieveGObject(hndl);
+	    Handle hndl = gtk_text_buffer_get_selection_bound(getHandle());
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (TextMark)obj;
 		return new TextMark(hndl);
@@ -496,8 +477,6 @@ public class TextBuffer extends GObject {
 	 * @param end Other bound of range to be tagged
 	 */
 	public void applyTag(String name, TextIter start, TextIter end) {
-	    if (null == name)
-	        name = "";
 		gtk_text_buffer_apply_tag_by_name(getHandle(), name, start.getHandle(), end.getHandle());
 	}
 
@@ -508,8 +487,6 @@ public class TextBuffer extends GObject {
 	 * @param end Other bound of range to be untagged
 	 */
 	public void removeTag(String name, TextIter start, TextIter end) {
-	    if (null == name)
-	        name = "";
 		gtk_text_buffer_remove_tag_by_name(getHandle(), name, start.getHandle(), end.getHandle());
 	}
 
@@ -517,7 +494,7 @@ public class TextBuffer extends GObject {
 	 * Removes all tags in the range between start and end. Be careful with this
 	 * function; it could remove tags added in code unrelated to the code you're
 	 * currently writing. That is, using this function is probably a bad idea if
-v	 * you have two or more unrelated code sections that add tags.
+	 * you have two or more unrelated code sections that add tags.
 	 * @param start One bound of range to be untagged
 	 * @param end Other bound of range to be untagged
 	 */
@@ -618,7 +595,7 @@ v	 * you have two or more unrelated code sections that add tags.
 	 * of the selection will be considered (users can't delete uneditable text).
 	 * @param interactive Whether the deletion is caused by user interaction
 	 * @param defaultEditable Whether the buffer is editable by default
-	 * @returns Whether there was a non-empty selection to delete
+	 * @return Whether there was a non-empty selection to delete
 	 */
 	public boolean deleteSelection(boolean interactive, boolean defaultEditable) {
 		return gtk_text_buffer_delete_selection(getHandle(), interactive, defaultEditable);
@@ -771,8 +748,8 @@ v	 * you have two or more unrelated code sections that add tags.
 		return cls;
 	}
 
-	public GtkEventType getEventType(String signal) {
-		GtkEventType et = evtMap.getEventType(signal);
+	public EventType getEventType(String signal) {
+		EventType et = evtMap.getEventType(signal);
 		if (et == null) et = super.getEventType(signal);
 		return et;
 	}
@@ -874,7 +851,7 @@ v	 * you have two or more unrelated code sections that add tags.
 		return list.indexOf(listener);
 	}
 
-	private void handleApplyTag(int tag, int startIter, int endIter) {
+	private void handleApplyTag(Handle tag, Handle startIter, Handle endIter) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.APPLY_TAG));
 	}
 
@@ -882,27 +859,27 @@ v	 * you have two or more unrelated code sections that add tags.
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.CHANGED));
 	}
 
-	private void handleDeleteRange(int startIter, int endIter) {
+	private void handleDeleteRange(Handle startIter, Handle endIter) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.DELETE_RANGE));
 	}
 
-	private void handleInsertChildAnchor(int position, int childAnchor) {
+	private void handleInsertChildAnchor(Handle position, Handle childAnchor) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.INSERT_CHILD_ANCHOR));
 	}
 
-	private void handleInsertPixbuf(int position, int pixbuf) {
+	private void handleInsertPixbuf(Handle position, Handle pixbuf) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.INSERT_PIXBUF));
 	}
 
-	private void handleInsertText(int position, String text, int length) {
+	private void handleInsertText(Handle position, String text, int length) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.INSERT_TEXT));
 	}
 
-	private void handleMarkDelete(int mark) {
+	private void handleMarkDelete(Handle mark) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.MARK_DELETED));
 	}
 
-	private void handleMarkSet(int location, int mark) {
+	private void handleMarkSet(Handle location, Handle mark) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.MARK_SET));
 	}
 
@@ -910,7 +887,7 @@ v	 * you have two or more unrelated code sections that add tags.
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.MODIFIED_CHANGED));
 	}
 
-	private void handleRemoveTag(int tag, int startChar, int endChar) {
+	private void handleRemoveTag(Handle tag, Handle startChar, Handle endChar) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.REMOVE_TAG));
 	}
 
@@ -928,78 +905,73 @@ v	 * you have two or more unrelated code sections that add tags.
 		return new TextTag(create_tag(getHandle(), name));
 	}
 
-	/****************************************
-	 * BEGINNING OF JNI CODE
-	 ****************************************/
 	native static final protected int gtk_text_buffer_get_type();
-	native static final protected int gtk_text_buffer_new(int table);
-	native static final protected int gtk_text_buffer_get_line_count(int buffer);
-	native static final protected int gtk_text_buffer_get_char_count(int buffer);
-	native static final protected int gtk_text_buffer_get_tag_table(int buffer);
-	native static final protected void gtk_text_buffer_set_text(int buffer, String text);
-	native static final protected void gtk_text_buffer_insert(int buffer, int iter, String text);
-	native static final protected void gtk_text_buffer_insert_at_cursor(int buffer, String text);
-	native static final protected boolean gtk_text_buffer_insert_interactive(int buffer, int iter, String text, boolean defaultEditable);
-	native static final protected boolean gtk_text_buffer_insert_interactive_at_cursor(int buffer, String text, boolean defaultEditable);
-	native static final protected void gtk_text_buffer_insert_range(int buffer, int iter, int start, int end);
-	native static final protected boolean gtk_text_buffer_insert_range_interactive(int buffer, int iter, int start, int end, boolean defaultEditable);
-	native static final protected void gtk_text_buffer_delete(int buffer, int start, int end);
-	native static final protected boolean gtk_text_buffer_delete_interactive(int buffer, int start, int end, boolean defaultEditable);
-	native static final protected String gtk_text_buffer_get_text(int buffer, int start, int end, boolean includeHiddenChars);
-	native static final protected String gtk_text_buffer_get_slice(int buffer, int start, int end, boolean includeHiddenChars);
-	native static final protected void gtk_text_buffer_insert_pixbuf(int buffer, int iter, int pixbuf);
-	native static final protected void gtk_text_buffer_insert_child_anchor(int buffer, int iter, int anchor);
-	native static final protected int gtk_text_buffer_create_child_anchor(int buffer, int iter);
-	native static final protected int gtk_text_buffer_create_mark(int buffer, String markName, int where, boolean leftGravity);
-	native static final protected void gtk_text_buffer_move_mark(int buffer, int mark, int where);
-	native static final protected void gtk_text_buffer_delete_mark(int buffer, int mark);
-	native static final protected int gtk_text_buffer_get_mark(int buffer, String name);
-	native static final protected void gtk_text_buffer_move_mark_by_name(int buffer, String name, int where);
-	native static final protected void gtk_text_buffer_delete_mark_by_name(int buffer, String name);
-	native static final protected int gtk_text_buffer_get_insert(int buffer);
-	native static final protected int gtk_text_buffer_get_selection_bound(int buffer);
-	native static final protected void gtk_text_buffer_place_cursor(int buffer, int where);
-	native static final protected void gtk_text_buffer_apply_tag(int buffer, int tag, int start, int end);
-	native static final protected void gtk_text_buffer_remove_tag(int buffer, int tag, int start, int end);
-	native static final protected void gtk_text_buffer_apply_tag_by_name(int buffer, String name, int start, int end);
-	native static final protected void gtk_text_buffer_remove_tag_by_name(int buffer, String name, int start, int end);
-	native static final protected void gtk_text_buffer_remove_all_tags(int buffer, int start, int end);
-	native static final protected void gtk_text_buffer_get_iter_at_line_offset(int buffer, int iter, int lineNumber, int charOffset);
-	native static final protected void gtk_text_buffer_get_iter_at_line_index(int buffer, int iter, int lineNumber, int byteIndex);
-	native static final protected void gtk_text_buffer_get_iter_at_offset(int buffer, int iter, int charOffset);
-	native static final protected void gtk_text_buffer_get_iter_at_line(int buffer, int iter, int lineNumber);
-	native static final protected void gtk_text_buffer_get_start_iter(int buffer, int iter);
-	native static final protected void gtk_text_buffer_get_end_iter(int buffer, int iter);
-	native static final protected void gtk_text_buffer_get_bounds(int buffer, int start, int end);
-	native static final protected void gtk_text_buffer_get_iter_at_mark(int buffer, int iter, int mark);
-	native static final protected void gtk_text_buffer_get_iter_at_child_anchor(int buffer, int iter, int anchor);
-	native static final protected boolean gtk_text_buffer_get_modified(int buffer);
-	native static final protected void gtk_text_buffer_set_modified(int buffer, boolean setting);
-	native static final protected void gtk_text_buffer_add_selection_clipboard(int buffer, int clipboard);
-	native static final protected void gtk_text_buffer_remove_selection_clipboard(int buffer, int clipboard);
-	native static final protected void gtk_text_buffer_cut_clipboard(int buffer, int clipboard, boolean defaultEditable);
-	native static final protected void gtk_text_buffer_copy_clipboard(int buffer, int clipboard);
-	native static final protected void gtk_text_buffer_paste_clipboard(int buffer, int clipboard, int overrideLocation, boolean defaultEditable);
-	native static final protected boolean gtk_text_buffer_get_selection_bounds(int buffer, int start, int end);
-	native static final protected boolean gtk_text_buffer_delete_selection(int buffer, boolean interactive, boolean defaultEditable);
-	native static final protected void gtk_text_buffer_begin_user_action(int buffer);
-	native static final protected void gtk_text_buffer_end_user_action(int buffer);
-	native static final protected int gtk_text_buffer_new_noTable();
-	native static final protected int create_tag(int buffer, String name);
-	native static final protected void insert_with_tag( int buffer, int iter, String text, String tag );
-	native static final protected void gtk_text_buffer_select_range    (int handle, int ins, int bound );
-	native protected static final boolean gtk_text_buffer_get_selection_exists(int handle);
-	native protected static final int gtk_text_buffer_get_selection_start(int handle);
-	native protected static final int gtk_text_buffer_get_selection_end(int handle);
-	native static final protected int gtk_text_buffer_get_iter_at_line_offsetMOD(int buffer, int lineNumber, int charOffset);
-	native static final protected int gtk_text_buffer_get_iter_at_offsetMOD(int buffer, int charOffset);
-	native static final protected int gtk_text_buffer_get_iter_at_lineMOD(int buffer, int line);
-	native static final protected int gtk_text_buffer_get_iter_at_markMOD(int buffer, int mark);
-	native static final protected int gtk_text_buffer_get_iter_at_child_anchorMOD(int buffer, int anchor);
-	native static final protected int gtk_text_buffer_get_start_iterMOD(int buffer);
-	native static final protected int gtk_text_buffer_get_end_iterMOD(int buffer);
-	native protected static final void gtk_text_buffer_paste_clipboardInsertPosition(int handle, int clip, boolean editable);
-	/****************************************
-	 * END OF JNI CODE
-	 ****************************************/
+	native static final protected Handle gtk_text_buffer_new(Handle table);
+	native static final protected int gtk_text_buffer_get_line_count(Handle buffer);
+	native static final protected int gtk_text_buffer_get_char_count(Handle buffer);
+	native static final protected Handle gtk_text_buffer_get_tag_table(Handle buffer);
+	native static final protected void gtk_text_buffer_set_text(Handle buffer, String text);
+	native static final protected void gtk_text_buffer_insert(Handle buffer, Handle iter, String text);
+	native static final protected void gtk_text_buffer_insert_at_cursor(Handle buffer, String text);
+	native static final protected boolean gtk_text_buffer_insert_interactive(Handle buffer, Handle iter, String text, boolean defaultEditable);
+	native static final protected boolean gtk_text_buffer_insert_interactive_at_cursor(Handle buffer, String text, boolean defaultEditable);
+	native static final protected void gtk_text_buffer_insert_range(Handle buffer, Handle iter, Handle start, Handle end);
+	native static final protected boolean gtk_text_buffer_insert_range_interactive(Handle buffer, Handle iter, Handle start, Handle end, boolean defaultEditable);
+	native static final protected void gtk_text_buffer_delete(Handle buffer, Handle start, Handle end);
+	native static final protected boolean gtk_text_buffer_delete_interactive(Handle buffer, Handle start, Handle end, boolean defaultEditable);
+	native static final protected String gtk_text_buffer_get_text(Handle buffer, Handle start, Handle end, boolean includeHiddenChars);
+	native static final protected String gtk_text_buffer_get_slice(Handle buffer, Handle start, Handle end, boolean includeHiddenChars);
+	native static final protected void gtk_text_buffer_insert_pixbuf(Handle buffer, Handle iter, Handle pixbuf);
+	native static final protected void gtk_text_buffer_insert_child_anchor(Handle buffer, Handle iter, Handle anchor);
+	native static final protected Handle gtk_text_buffer_create_child_anchor(Handle buffer, Handle iter);
+	native static final protected Handle gtk_text_buffer_create_mark(Handle buffer, String markName, Handle where, boolean leftGravity);
+	native static final protected void gtk_text_buffer_move_mark(Handle buffer, Handle mark, Handle where);
+	native static final protected void gtk_text_buffer_delete_mark(Handle buffer, Handle mark);
+	native static final protected Handle gtk_text_buffer_get_mark(Handle buffer, String name);
+	native static final protected void gtk_text_buffer_move_mark_by_name(Handle buffer, String name, Handle where);
+	native static final protected void gtk_text_buffer_delete_mark_by_name(Handle buffer, String name);
+	native static final protected Handle gtk_text_buffer_get_insert(Handle buffer);
+	native static final protected Handle gtk_text_buffer_get_selection_bound(Handle buffer);
+	native static final protected void gtk_text_buffer_place_cursor(Handle buffer, Handle where);
+	native static final protected void gtk_text_buffer_apply_tag(Handle buffer, Handle tag, Handle start, Handle end);
+	native static final protected void gtk_text_buffer_remove_tag(Handle buffer, Handle tag, Handle start, Handle end);
+	native static final protected void gtk_text_buffer_apply_tag_by_name(Handle buffer, String name, Handle start, Handle end);
+	native static final protected void gtk_text_buffer_remove_tag_by_name(Handle buffer, String name, Handle start, Handle end);
+	native static final protected void gtk_text_buffer_remove_all_tags(Handle buffer, Handle start, Handle end);
+	native static final protected void gtk_text_buffer_get_iter_at_line_offset(Handle buffer, Handle iter, int lineNumber, int charOffset);
+	native static final protected void gtk_text_buffer_get_iter_at_line_index(Handle buffer, Handle iter, int lineNumber, int byteIndex);
+	native static final protected void gtk_text_buffer_get_iter_at_offset(Handle buffer, Handle iter, int charOffset);
+	native static final protected void gtk_text_buffer_get_iter_at_line(Handle buffer, Handle iter, int lineNumber);
+	native static final protected void gtk_text_buffer_get_start_iter(Handle buffer, Handle iter);
+	native static final protected void gtk_text_buffer_get_end_iter(Handle buffer, Handle iter);
+	native static final protected void gtk_text_buffer_get_bounds(Handle buffer, int start, int end);
+	native static final protected void gtk_text_buffer_get_iter_at_mark(Handle buffer, Handle iter, int mark);
+	native static final protected void gtk_text_buffer_get_iter_at_child_anchor(Handle buffer, Handle iter, int anchor);
+	native static final protected boolean gtk_text_buffer_get_modified(Handle buffer);
+	native static final protected void gtk_text_buffer_set_modified(Handle buffer, boolean setting);
+	native static final protected void gtk_text_buffer_add_selection_clipboard(Handle buffer, Handle clipboard);
+	native static final protected void gtk_text_buffer_remove_selection_clipboard(Handle buffer, Handle clipboard);
+	native static final protected void gtk_text_buffer_cut_clipboard(Handle buffer, Handle clipboard, boolean defaultEditable);
+	native static final protected void gtk_text_buffer_copy_clipboard(Handle buffer, Handle clipboard);
+	native static final protected void gtk_text_buffer_paste_clipboard(Handle buffer, Handle clipboard, Handle overrideLocation, boolean defaultEditable);
+	native static final protected boolean gtk_text_buffer_get_selection_bounds(Handle buffer, int start, int end);
+	native static final protected boolean gtk_text_buffer_delete_selection(Handle buffer, boolean interactive, boolean defaultEditable);
+	native static final protected void gtk_text_buffer_begin_user_action(Handle buffer);
+	native static final protected void gtk_text_buffer_end_user_action(Handle buffer);
+	native static final protected Handle gtk_text_buffer_new_noTable();
+	native static final protected Handle create_tag(Handle buffer, String name);
+	native static final protected void insert_with_tag( Handle buffer, Handle iter, String text, String tag );
+	native static final protected void gtk_text_buffer_select_range(Handle handle, Handle ins, Handle bound );
+	native protected static final boolean gtk_text_buffer_get_selection_exists(Handle handle);
+	native protected static final Handle gtk_text_buffer_get_selection_start(Handle handle);
+	native protected static final Handle gtk_text_buffer_get_selection_end(Handle handle);
+	native static final protected Handle gtk_text_buffer_get_iter_at_line_offsetMOD(Handle buffer, int lineNumber, int charOffset);
+	native static final protected Handle gtk_text_buffer_get_iter_at_offsetMOD(Handle buffer, int charOffset);
+	native static final protected Handle gtk_text_buffer_get_iter_at_lineMOD(Handle buffer, int line);
+	native static final protected Handle gtk_text_buffer_get_iter_at_markMOD(Handle buffer, Handle mark);
+	native static final protected Handle gtk_text_buffer_get_iter_at_child_anchorMOD(Handle buffer, Handle anchor);
+	native static final protected Handle gtk_text_buffer_get_start_iterMOD(Handle buffer);
+	native static final protected Handle gtk_text_buffer_get_end_iterMOD(Handle buffer);
+	native protected static final void gtk_text_buffer_paste_clipboardInsertPosition(Handle handle, Handle clip, boolean editable);
+
 }
